IndefiniteRotation3DEffect class

A widget that applies 3D rotation to its child, supporting both gesture-driven and continuous or finite auto-rotation on the X axis, Y axis, or both.

Inheritance

Constructors

IndefiniteRotation3DEffect({Key? key, required Widget child, bool autoRotate = true, int? rotationCount, bool rotateX = true, bool rotateY = false, Duration rotationDuration = const Duration(seconds: 5), bool allowUserRotation = true, bool stopRotationOnUserInteraction = false, double gestureSensitivity = 0.01})
const

Properties

allowUserRotation bool
If true, user can pan to rotate the widget.
final
autoRotate bool
If true and rotationCount is null, auto-rotation runs continuously.
final
child Widget
The widget to be rotated.
final
gestureSensitivity double
Multiplier controlling how sensitive user drag is (radians per pixel).
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rotateX bool
Whether to rotate around the X axis.
final
rotateY bool
Whether to rotate around the Y axis.
final
rotationCount int?
If non-null, runs a finite number of full rotations, overriding autoRotate.
final
rotationDuration Duration
Duration for one full 360° rotation cycle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopRotationOnUserInteraction bool
If true, it will stop rotating when the user interacts.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<IndefiniteRotation3DEffect>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited